import * as i0 from '@angular/core';
import { Input, ViewChild, ChangeDetectionStrategy, Component, Directive, NO_ERRORS_SCHEMA, CUSTOM_ELEMENTS_SCHEMA, NgModule } from '@angular/core';
import * as i1 from 'barsa-novin-ray-core';
import { BaseComponent, BaseDirective, BarsaApi, BarsaNovinRayCoreModule } from 'barsa-novin-ray-core';
import * as i1$1 from '@angular/common';
import { CommonModule } from '@angular/common';

class MicroChartBulletComponent extends BaseComponent {
    constructor(renderer) {
        super();
        this.renderer = renderer;
        this.suffix = '';
        this.separatorLinesFakeArray = [];
    }
    ngOnInit() {
        super.ngOnInit();
        this.delta = Math.abs(this.value - this.target);
        this.forecastWidth = this.getWidth(this.forecast);
        this.deltaWidth = this.getWidth(this.delta);
        this.valueWidth = this.getWidth(this.value);
        this.targetWidth = this.getWidth(this.target, true);
        this.deltaBackgroundColor = this.getBackgroundColor('delta');
        this.forecastBackgroundColor = this.getBackgroundColor('forecast');
        this.valueBackgroundColor = this.getBackgroundColor('value');
        this.targetWithSuffix = this.getValueWithSuffix(this.target);
        this.deltaWithSuffix = this.getValueWithSuffix(this.delta);
        this.valueWithSuffix = this.getValueWithSuffix(this.value);
        this.fakeArray();
    }
    ngAfterViewInit() {
        super.ngAfterViewInit();
        if (this.deltaDom) {
            const deltaLeft = this.value >= this.target ? this.getWidth(this.target) : this.getWidth(this.target - this.delta);
            this.renderer.setStyle(this.deltaDom.nativeElement, 'left', deltaLeft);
            const deltaPointerDom = this.deltaDom.nativeElement.querySelector('.pointer');
            const deltaPointerLeft = this.value >= this.target ? '' : '0';
            this.renderer.setStyle(deltaPointerDom, 'left', deltaPointerLeft);
        }
    }
    getWidth(value, isTarget) {
        if (value) {
            let width = (value / this.range) * 100;
            width = isTarget ? width - 2 : width;
            return width.toString() + '%';
        }
        else {
            return '0';
        }
    }
    getValueWithSuffix(value) {
        return value.toString() + (this.suffix || '');
    }
    getBackgroundColor(item) {
        if (item === 'forecast') {
            return this.forecast >= this.target ? '#a1dbb1' : '#fda8ab';
        }
        else {
            return this.value >= this.target ? '#3fa45b' : '#dc0d0e';
        }
    }
    fakeArray() {
        for (let i = 0; i < this.separatorLines; i++) {
            this.separatorLinesFakeArray.push(i);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartBulletComponent, deps: [{ token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "19.2.10", type: MicroChartBulletComponent, isStandalone: false, selector: "be-micro-chart-bullet", inputs: { chartInstanceId: "chartInstanceId", parentMoId: "parentMoId", range: "range", value: "value", forecast: "forecast", target: "target", suffix: "suffix", separatorLines: "separatorLines", isDelta: "isDelta" }, viewQueries: [{ propertyName: "deltaDom", first: true, predicate: ["deltaBox"], descendants: true }], usesInheritance: true, ngImport: i0, template: "<div class=\"chart-container\">\r\n    <div class=\"range\">\r\n        @if (target) {\r\n        <div class=\"target\" #target [style.left]=\"targetWidth\">\r\n            <span>{{ targetWithSuffix }}</span>\r\n        </div>\r\n        } @if (forecast) {\r\n        <div class=\"forecast\" [style.background-color]=\"forecastBackgroundColor\" [style.width]=\"forecastWidth\"></div>\r\n        } @if (isDelta && delta) {\r\n        <div class=\"delta\" #deltaBox [style.background-color]=\"deltaBackgroundColor\" [style.width]=\"deltaWidth\">\r\n            <span [style.color]=\"valueBackgroundColor\">{{ deltaWithSuffix + '\u25B2' }}</span>\r\n            <div class=\"pointer\" [style.background-color]=\"deltaBackgroundColor\"></div>\r\n        </div>\r\n        } @else { @if (value) {\r\n        <div class=\"value\" [style.background-color]=\"valueBackgroundColor\" [style.width]=\"valueWidth\">\r\n            <span [style.color]=\"valueBackgroundColor\">{{ valueWithSuffix }}</span>\r\n            <div class=\"pointer\" [style.background-color]=\"valueBackgroundColor\"></div>\r\n        </div>\r\n        } }\r\n\r\n        <!--  separator lines-->\r\n    </div>\r\n    @if (separatorLines) {\r\n    <div class=\"separator-lines\">\r\n        @for (i of separatorLinesFakeArray; track i) {\r\n        <div class=\"separator-line\"></div>\r\n        }\r\n    </div>\r\n    }\r\n</div>\r\n", styles: [".separator-lines,.range .value,.range .target,.range .forecast,.range{margin-bottom:auto;margin-top:auto;top:0;bottom:0}:host{display:flex;width:100%;height:100%;align-items:center}.chart-container{height:15px;width:100%;position:relative}.range{width:100%;position:absolute;background-color:#e6eee8;z-index:2}.range .forecast{position:absolute;left:0}.range .target{position:absolute;z-index:5;width:2%;height:24px;background-color:#000}.range .target span{position:absolute;bottom:-20px;right:-10px}.range .value{position:absolute;left:0;height:7px}.range .value .pointer{position:absolute;width:2px;height:20px;bottom:0}.range .value span{position:absolute;bottom:19px;right:-6px}.range .delta{position:absolute;height:15px}.range .delta .pointer{position:absolute;width:2px;height:20px;bottom:0}.range .delta span{position:absolute;bottom:19px}.separator-lines{position:absolute;display:flex;justify-content:space-between;height:20px;width:100%}.separator-lines .separator-line{background-color:#e9730c;width:2px}.separator-lines .separator-line:first-child,.separator-lines .separator-line:last-child{background-color:#c21a1a!important}\n"], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartBulletComponent, decorators: [{
            type: Component,
            args: [{ selector: 'be-micro-chart-bullet', changeDetection: ChangeDetectionStrategy.OnPush, standalone: false, template: "<div class=\"chart-container\">\r\n    <div class=\"range\">\r\n        @if (target) {\r\n        <div class=\"target\" #target [style.left]=\"targetWidth\">\r\n            <span>{{ targetWithSuffix }}</span>\r\n        </div>\r\n        } @if (forecast) {\r\n        <div class=\"forecast\" [style.background-color]=\"forecastBackgroundColor\" [style.width]=\"forecastWidth\"></div>\r\n        } @if (isDelta && delta) {\r\n        <div class=\"delta\" #deltaBox [style.background-color]=\"deltaBackgroundColor\" [style.width]=\"deltaWidth\">\r\n            <span [style.color]=\"valueBackgroundColor\">{{ deltaWithSuffix + '\u25B2' }}</span>\r\n            <div class=\"pointer\" [style.background-color]=\"deltaBackgroundColor\"></div>\r\n        </div>\r\n        } @else { @if (value) {\r\n        <div class=\"value\" [style.background-color]=\"valueBackgroundColor\" [style.width]=\"valueWidth\">\r\n            <span [style.color]=\"valueBackgroundColor\">{{ valueWithSuffix }}</span>\r\n            <div class=\"pointer\" [style.background-color]=\"valueBackgroundColor\"></div>\r\n        </div>\r\n        } }\r\n\r\n        <!--  separator lines-->\r\n    </div>\r\n    @if (separatorLines) {\r\n    <div class=\"separator-lines\">\r\n        @for (i of separatorLinesFakeArray; track i) {\r\n        <div class=\"separator-line\"></div>\r\n        }\r\n    </div>\r\n    }\r\n</div>\r\n", styles: [".separator-lines,.range .value,.range .target,.range .forecast,.range{margin-bottom:auto;margin-top:auto;top:0;bottom:0}:host{display:flex;width:100%;height:100%;align-items:center}.chart-container{height:15px;width:100%;position:relative}.range{width:100%;position:absolute;background-color:#e6eee8;z-index:2}.range .forecast{position:absolute;left:0}.range .target{position:absolute;z-index:5;width:2%;height:24px;background-color:#000}.range .target span{position:absolute;bottom:-20px;right:-10px}.range .value{position:absolute;left:0;height:7px}.range .value .pointer{position:absolute;width:2px;height:20px;bottom:0}.range .value span{position:absolute;bottom:19px;right:-6px}.range .delta{position:absolute;height:15px}.range .delta .pointer{position:absolute;width:2px;height:20px;bottom:0}.range .delta span{position:absolute;bottom:19px}.separator-lines{position:absolute;display:flex;justify-content:space-between;height:20px;width:100%}.separator-lines .separator-line{background-color:#e9730c;width:2px}.separator-lines .separator-line:first-child,.separator-lines .separator-line:last-child{background-color:#c21a1a!important}\n"] }]
        }], ctorParameters: () => [{ type: i0.Renderer2 }], propDecorators: { chartInstanceId: [{
                type: Input
            }], parentMoId: [{
                type: Input
            }], deltaDom: [{
                type: ViewChild,
                args: ['deltaBox']
            }], range: [{
                type: Input
            }], value: [{
                type: Input
            }], forecast: [{
                type: Input
            }], target: [{
                type: Input
            }], suffix: [{
                type: Input
            }], separatorLines: [{
                type: Input
            }], isDelta: [{
                type: Input
            }] } });

class ChartBaseDirective extends BaseDirective {
    constructor(_el, renderer2, _cdr) {
        super(_el);
        this._el = _el;
        this.renderer2 = renderer2;
        this._cdr = _cdr;
    }
    ngOnInit() {
        // set some style to chart
        super.ngOnInit();
        const elDom = this._el.nativeElement;
        this.renderer2.setStyle(elDom, 'width', '100%');
        this.renderer2.setStyle(elDom, 'height', '100%');
        this.renderer2.setStyle(elDom, 'display', 'block');
    }
    ngAfterViewInit() {
        this._loadChartInstance(this.chartInstanceId, this.parentMoId);
    }
    resize() {
        this.chart?.resize();
    }
    _renderChart() {
        setTimeout(() => {
            head.load(['Lib/Echarts/echarts.My.min.js'], () => {
                const elDom = this._el.nativeElement;
                this.chart = echarts.init(elDom);
                this.chart.setOption(this.chartOption);
            });
        }, 300);
    }
    _loadChartInstance(chartInstanceId, parentMoId = null) {
        BarsaApi.Bw.RunBlMethodAsync({
            Parameters: [chartInstanceId, parentMoId],
            Method: 'BarsaGetChartOptions',
            SuccessFn: (chartOption) => {
                this.chartOption = BarsaApi.Ext.decode(chartOption);
                this._renderChart();
                this._cdr.detectChanges();
            },
            FailFn: () => { }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: ChartBaseDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "19.2.10", type: ChartBaseDirective, isStandalone: false, selector: "[echartRenderer]", inputs: { chartInstanceId: "chartInstanceId", parentMoId: "parentMoId" }, exportAs: ["echartRenderer"], usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: ChartBaseDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[echartRenderer]',
                    exportAs: 'echartRenderer',
                    standalone: false
                }]
        }], ctorParameters: () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.ChangeDetectorRef }], propDecorators: { chartInstanceId: [{
                type: Input
            }], parentMoId: [{
                type: Input
            }] } });

class MicroChartLineComponent extends BaseComponent {
    constructor(el) {
        super();
        this.el = el;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartLineComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.10", type: MicroChartLineComponent, isStandalone: false, selector: "be-micro-chart-line", inputs: { chartInstanceId: "chartInstanceId", parentMoId: "parentMoId" }, usesInheritance: true, ngImport: i0, template: "<!-- <div class=\"top-labels\">\r\n    <span>{{ lastValue }}{{ line?.suffix }}</span>\r\n    <span>{{ firstValue }}{{ line?.suffix }}</span>\r\n</div> -->\r\n\r\n<div class=\"chart\">\r\n    <div *untilInView=\"el\" echartRenderer [chartInstanceId]=\"chartInstanceId\" [parentMoId]=\"parentMoId\"></div>\r\n</div>\r\n<!-- \r\n<div class=\"bottom-labels\">\r\n    <span>{{ lastLabel }}</span>\r\n    <span>{{ firstLabel }}</span>\r\n</div> -->\r\n", styles: [":host{display:block;width:100%;height:100%}.chart{width:100%;height:52%}span{margin:0;font-size:10px}.top-labels{width:100%;height:23%;display:flex;justify-content:space-between}.bottom-labels{width:100%;height:25%;display:flex;justify-content:space-between}\n"], dependencies: [{ kind: "directive", type: i1.UntilInViewDirective, selector: "[untilInView]", inputs: ["untilInView", "intersectionDebounce"] }, { kind: "directive", type: ChartBaseDirective, selector: "[echartRenderer]", inputs: ["chartInstanceId", "parentMoId"], exportAs: ["echartRenderer"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartLineComponent, decorators: [{
            type: Component,
            args: [{ selector: 'be-micro-chart-line', changeDetection: ChangeDetectionStrategy.OnPush, standalone: false, template: "<!-- <div class=\"top-labels\">\r\n    <span>{{ lastValue }}{{ line?.suffix }}</span>\r\n    <span>{{ firstValue }}{{ line?.suffix }}</span>\r\n</div> -->\r\n\r\n<div class=\"chart\">\r\n    <div *untilInView=\"el\" echartRenderer [chartInstanceId]=\"chartInstanceId\" [parentMoId]=\"parentMoId\"></div>\r\n</div>\r\n<!-- \r\n<div class=\"bottom-labels\">\r\n    <span>{{ lastLabel }}</span>\r\n    <span>{{ firstLabel }}</span>\r\n</div> -->\r\n", styles: [":host{display:block;width:100%;height:100%}.chart{width:100%;height:52%}span{margin:0;font-size:10px}.top-labels{width:100%;height:23%;display:flex;justify-content:space-between}.bottom-labels{width:100%;height:25%;display:flex;justify-content:space-between}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { chartInstanceId: [{
                type: Input
            }], parentMoId: [{
                type: Input
            }] } });

class MicroChartStackbarComponent extends BaseComponent {
    constructor(el) {
        super();
        this.el = el;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartStackbarComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.10", type: MicroChartStackbarComponent, isStandalone: false, selector: "be-micro-chart-stackbar", inputs: { chartInstanceId: "chartInstanceId", parentMoId: "parentMoId" }, usesInheritance: true, ngImport: i0, template: "<div *untilInView=\"el\" echartRenderer class=\"chart\" [chartInstanceId]=\"chartInstanceId\" [parentMoId]=\"parentMoId\"></div>\r\n", styles: [":host{display:block;width:100%;height:100%}.chart{width:100%}\n"], dependencies: [{ kind: "directive", type: i1.UntilInViewDirective, selector: "[untilInView]", inputs: ["untilInView", "intersectionDebounce"] }, { kind: "directive", type: ChartBaseDirective, selector: "[echartRenderer]", inputs: ["chartInstanceId", "parentMoId"], exportAs: ["echartRenderer"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartStackbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'be-micro-chart-stackbar', changeDetection: ChangeDetectionStrategy.OnPush, standalone: false, template: "<div *untilInView=\"el\" echartRenderer class=\"chart\" [chartInstanceId]=\"chartInstanceId\" [parentMoId]=\"parentMoId\"></div>\r\n", styles: [":host{display:block;width:100%;height:100%}.chart{width:100%}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { chartInstanceId: [{
                type: Input
            }], parentMoId: [{
                type: Input
            }] } });

class MicroChartCircularComponent extends BaseComponent {
    constructor(el) {
        super();
        this.el = el;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartCircularComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.10", type: MicroChartCircularComponent, isStandalone: false, selector: "be-micro-chart-circular", inputs: { chartInstanceId: "chartInstanceId", parentMoId: "parentMoId" }, usesInheritance: true, ngImport: i0, template: "<div *untilInView=\"el\" echartRenderer [chartInstanceId]=\"chartInstanceId\" [parentMoId]=\"parentMoId\"></div>\r\n", styles: [":host{display:block;width:100%;height:100%}\n"], dependencies: [{ kind: "directive", type: i1.UntilInViewDirective, selector: "[untilInView]", inputs: ["untilInView", "intersectionDebounce"] }, { kind: "directive", type: ChartBaseDirective, selector: "[echartRenderer]", inputs: ["chartInstanceId", "parentMoId"], exportAs: ["echartRenderer"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartCircularComponent, decorators: [{
            type: Component,
            args: [{ selector: 'be-micro-chart-circular', changeDetection: ChangeDetectionStrategy.OnPush, standalone: false, template: "<div *untilInView=\"el\" echartRenderer [chartInstanceId]=\"chartInstanceId\" [parentMoId]=\"parentMoId\"></div>\r\n", styles: [":host{display:block;width:100%;height:100%}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { chartInstanceId: [{
                type: Input
            }], parentMoId: [{
                type: Input
            }] } });

class MicroChartComparisonComponent extends BaseComponent {
    constructor(el) {
        super();
        this.el = el;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartComparisonComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.10", type: MicroChartComparisonComponent, isStandalone: false, selector: "be-micro-chart-comparison", inputs: { chartInstanceId: "chartInstanceId", parentMoId: "parentMoId", size: "size" }, usesInheritance: true, ngImport: i0, template: "<div *untilInView=\"el\" echartRenderer [chartInstanceId]=\"chartInstanceId\" [parentMoId]=\"parentMoId\"></div>\r\n", styles: [":host{display:block;width:100%;height:100%}\n"], dependencies: [{ kind: "directive", type: i1.UntilInViewDirective, selector: "[untilInView]", inputs: ["untilInView", "intersectionDebounce"] }, { kind: "directive", type: ChartBaseDirective, selector: "[echartRenderer]", inputs: ["chartInstanceId", "parentMoId"], exportAs: ["echartRenderer"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartComparisonComponent, decorators: [{
            type: Component,
            args: [{ selector: 'be-micro-chart-comparison', changeDetection: ChangeDetectionStrategy.OnPush, standalone: false, template: "<div *untilInView=\"el\" echartRenderer [chartInstanceId]=\"chartInstanceId\" [parentMoId]=\"parentMoId\"></div>\r\n", styles: [":host{display:block;width:100%;height:100%}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { chartInstanceId: [{
                type: Input
            }], parentMoId: [{
                type: Input
            }], size: [{
                type: Input
            }] } });

class MicroChartAreaComponent extends BaseComponent {
    constructor(el) {
        super();
        this.el = el;
    }
    ngOnInit() {
        super.ngOnInit();
        this.suffix = this.chartData?.line?.suffix;
        this.getFirstAndLastValues();
    }
    getFirstAndLastValues() {
        if (this.chartData) {
            const dataLength = this.chartData.line.data.length;
            this.firstValue = this.chartData.line.data[0].value.toString();
            this.lastValue = this.chartData.line.data[dataLength - 1].value.toString();
            this.firstLabel = this.chartData.line.data[0].label;
            this.lastLabel = this.chartData.line.data[dataLength - 1].label;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartAreaComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.10", type: MicroChartAreaComponent, isStandalone: false, selector: "be-micro-chart-area", inputs: { chartInstanceId: "chartInstanceId", parentMoId: "parentMoId", size: "size", chartData: "chartData" }, usesInheritance: true, ngImport: i0, template: "<!-- @if (size === 'l') {\r\n<div class=\"right-labels\">\r\n    <span [style.color]=\"chartData.lastValueColor\">{{ lastValue }}{{ chartData?.line?.suffix }}</span>\r\n    <span [style.color]=\"chartData.lastValueColor\">{{ lastLabel }}</span>\r\n</div>\r\n} @if (size === 's') {\r\n<div class=\"top-labels\">\r\n    <span [style.color]=\"chartData.lastValueColor\">{{ lastValue }}{{ suffix }}</span>\r\n    <span [style.color]=\"chartData.firstValueColor\">{{ firstValue }}{{ suffix }}</span>\r\n</div>\r\n} -->\r\n\r\n<div *untilInView=\"el\" echartRenderer [chartInstanceId]=\"chartInstanceId\" [parentMoId]=\"parentMoId\"></div>\r\n<!-- \r\n@if (size === 'l') {\r\n<div class=\"left-labels\">\r\n    <span [style.color]=\"chartData.firstValueColor\">{{ firstValue }}{{ suffix }}</span>\r\n    <span [style.color]=\"chartData.firstValueColor\">{{ firstLabel }}</span>\r\n</div>\r\n} @if (size === 's') {\r\n<div class=\"bottom-labels\">\r\n    <span [style.color]=\"chartData.lastValueColor\">{{ lastLabel }}</span>\r\n    <span [style.color]=\"chartData.firstValueColor\">{{ firstLabel }}</span>\r\n</div>\r\n} -->\r\n", styles: [":host{display:block;width:100%;height:100%}span{margin:0;font-size:10px}.top-labels{width:100%;height:23%;display:flex;justify-content:space-between}.bottom-labels{width:100%;height:25%;display:flex;justify-content:space-between}.right-labels{min-width:40px;display:flex;flex-direction:column;justify-content:space-between;text-align:right}.left-labels{min-width:40px;display:flex;flex-direction:column;justify-content:space-between;text-align:left}\n"], dependencies: [{ kind: "directive", type: i1.UntilInViewDirective, selector: "[untilInView]", inputs: ["untilInView", "intersectionDebounce"] }, { kind: "directive", type: ChartBaseDirective, selector: "[echartRenderer]", inputs: ["chartInstanceId", "parentMoId"], exportAs: ["echartRenderer"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartAreaComponent, decorators: [{
            type: Component,
            args: [{ selector: 'be-micro-chart-area', changeDetection: ChangeDetectionStrategy.OnPush, standalone: false, template: "<!-- @if (size === 'l') {\r\n<div class=\"right-labels\">\r\n    <span [style.color]=\"chartData.lastValueColor\">{{ lastValue }}{{ chartData?.line?.suffix }}</span>\r\n    <span [style.color]=\"chartData.lastValueColor\">{{ lastLabel }}</span>\r\n</div>\r\n} @if (size === 's') {\r\n<div class=\"top-labels\">\r\n    <span [style.color]=\"chartData.lastValueColor\">{{ lastValue }}{{ suffix }}</span>\r\n    <span [style.color]=\"chartData.firstValueColor\">{{ firstValue }}{{ suffix }}</span>\r\n</div>\r\n} -->\r\n\r\n<div *untilInView=\"el\" echartRenderer [chartInstanceId]=\"chartInstanceId\" [parentMoId]=\"parentMoId\"></div>\r\n<!-- \r\n@if (size === 'l') {\r\n<div class=\"left-labels\">\r\n    <span [style.color]=\"chartData.firstValueColor\">{{ firstValue }}{{ suffix }}</span>\r\n    <span [style.color]=\"chartData.firstValueColor\">{{ firstLabel }}</span>\r\n</div>\r\n} @if (size === 's') {\r\n<div class=\"bottom-labels\">\r\n    <span [style.color]=\"chartData.lastValueColor\">{{ lastLabel }}</span>\r\n    <span [style.color]=\"chartData.firstValueColor\">{{ firstLabel }}</span>\r\n</div>\r\n} -->\r\n", styles: [":host{display:block;width:100%;height:100%}span{margin:0;font-size:10px}.top-labels{width:100%;height:23%;display:flex;justify-content:space-between}.bottom-labels{width:100%;height:25%;display:flex;justify-content:space-between}.right-labels{min-width:40px;display:flex;flex-direction:column;justify-content:space-between;text-align:right}.left-labels{min-width:40px;display:flex;flex-direction:column;justify-content:space-between;text-align:left}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { chartInstanceId: [{
                type: Input
            }], parentMoId: [{
                type: Input
            }], size: [{
                type: Input
            }], chartData: [{
                type: Input
            }] } });

class MicroChartBarComponent extends BaseComponent {
    constructor(el) {
        super();
        this.el = el;
    }
    onVisibilityChange(e) {
        if (e === 'Visible') {
            this.eChartBase.resize();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartBarComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "19.2.10", type: MicroChartBarComponent, isStandalone: false, selector: "be-micro-chart-bar", inputs: { chartInstanceId: "chartInstanceId", parentMoId: "parentMoId", size: "size", extraData: "extraData" }, viewQueries: [{ propertyName: "eChartBase", first: true, predicate: ["echartRenderer"], descendants: true }], usesInheritance: true, ngImport: i0, template: "<div\r\n    echartRenderer\r\n    #echartRenderer=\"echartRenderer\"\r\n    [ngClass]=\"size === 'l' ? 'flex-50' : 'flex-100'\"\r\n    [chartInstanceId]=\"chartInstanceId\"\r\n    [parentMoId]=\"parentMoId\"\r\n    intersectionObserver\r\n    [intersectionThreshold]=\"0.1\"\r\n    (visibilityChange)=\"onVisibilityChange($event)\"\r\n></div>\r\n<!-- @if (size === 'l') {\r\n<div class=\"chart-desc\">\r\n    <h2>{{ extraData.value }}{{ extraData.suffix }}</h2>\r\n</div>\r\n} -->\r\n", styles: [":host{display:flex;width:100%;height:100%}.flex-50,.flex-100{flex:50%}.chart-desc{flex:50%;display:flex;align-items:flex-end;justify-content:flex-end}.chart-desc h2{margin:0}\n"], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.IntersectionObserverDirective, selector: "[intersectionObserver]", inputs: ["intersectionDebounce", "intersectionRootMargin", "intersectionRoot", "intersectionThreshold"], outputs: ["visibilityChange"] }, { kind: "directive", type: ChartBaseDirective, selector: "[echartRenderer]", inputs: ["chartInstanceId", "parentMoId"], exportAs: ["echartRenderer"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: MicroChartBarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'be-micro-chart-bar', changeDetection: ChangeDetectionStrategy.OnPush, standalone: false, template: "<div\r\n    echartRenderer\r\n    #echartRenderer=\"echartRenderer\"\r\n    [ngClass]=\"size === 'l' ? 'flex-50' : 'flex-100'\"\r\n    [chartInstanceId]=\"chartInstanceId\"\r\n    [parentMoId]=\"parentMoId\"\r\n    intersectionObserver\r\n    [intersectionThreshold]=\"0.1\"\r\n    (visibilityChange)=\"onVisibilityChange($event)\"\r\n></div>\r\n<!-- @if (size === 'l') {\r\n<div class=\"chart-desc\">\r\n    <h2>{{ extraData.value }}{{ extraData.suffix }}</h2>\r\n</div>\r\n} -->\r\n", styles: [":host{display:flex;width:100%;height:100%}.flex-50,.flex-100{flex:50%}.chart-desc{flex:50%;display:flex;align-items:flex-end;justify-content:flex-end}.chart-desc h2{margin:0}\n"] }]
        }], ctorParameters: () => [{ type: i0.ElementRef }], propDecorators: { eChartBase: [{
                type: ViewChild,
                args: ['echartRenderer']
            }], chartInstanceId: [{
                type: Input
            }], parentMoId: [{
                type: Input
            }], size: [{
                type: Input
            }], extraData: [{
                type: Input
            }] } });

const components = [
    MicroChartComparisonComponent,
    MicroChartAreaComponent,
    MicroChartBarComponent,
    MicroChartAreaComponent,
    MicroChartStackbarComponent,
    MicroChartCircularComponent,
    MicroChartLineComponent,
    MicroChartCircularComponent,
    MicroChartBulletComponent,
    ChartBaseDirective
];
class BarsaEchartsModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: BarsaEchartsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "19.2.10", ngImport: i0, type: BarsaEchartsModule, declarations: [MicroChartComparisonComponent,
            MicroChartAreaComponent,
            MicroChartBarComponent,
            MicroChartAreaComponent,
            MicroChartStackbarComponent,
            MicroChartCircularComponent,
            MicroChartLineComponent,
            MicroChartCircularComponent,
            MicroChartBulletComponent,
            ChartBaseDirective], imports: [CommonModule, BarsaNovinRayCoreModule], exports: [MicroChartComparisonComponent,
            MicroChartAreaComponent,
            MicroChartBarComponent,
            MicroChartAreaComponent,
            MicroChartStackbarComponent,
            MicroChartCircularComponent,
            MicroChartLineComponent,
            MicroChartCircularComponent,
            MicroChartBulletComponent,
            ChartBaseDirective] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: BarsaEchartsModule, imports: [CommonModule, BarsaNovinRayCoreModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "19.2.10", ngImport: i0, type: BarsaEchartsModule, decorators: [{
            type: NgModule,
            args: [{
                    schemas: [NO_ERRORS_SCHEMA, CUSTOM_ELEMENTS_SCHEMA],
                    imports: [CommonModule, BarsaNovinRayCoreModule],
                    declarations: [...components],
                    exports: [...components]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BarsaEchartsModule, ChartBaseDirective, MicroChartAreaComponent, MicroChartBarComponent, MicroChartBulletComponent, MicroChartCircularComponent, MicroChartComparisonComponent, MicroChartLineComponent, MicroChartStackbarComponent };
//# sourceMappingURL=barsa-echarts.mjs.map
